@@ -18,28 +18,20 @@ def main() -> None:
         with OutputFile(f"Dockerfile.test_{version}", args.check) as f:
             f.write(toolchain_full() + regtest(version))
 
-        with OutputFile(f"Dockerfile.prod_{version}", args.check) as f:
-            f.write(toolchain_full() + production(version))
-
         with OutputFile(f"Dockerfile.test_generic_{version}", args.check) as f:
             f.write(toolchain_full(target_cpu="generic") + regtest(version))
 
-        with OutputFile(f"Dockerfile.prod_generic_{version}", args.check) as f:
-            f.write(toolchain_full(target_cpu="generic") + production(version))
-
     with OutputFile(f"Dockerfile.test_openmpi-psmp", args.check) as f:
         # Also testing --with-gcc=install here, see github.com/cp2k/cp2k/issues/2062 .
         f.write(toolchain_full(mpi_mode="openmpi", with_gcc="install"))
         f.write(regtest("psmp"))
 
+    with OutputFile(f"Dockerfile.test_fedora-psmp", args.check) as f:
+        f.write(toolchain_full(base_image="fedora:38") + regtest("psmp"))
+
     with OutputFile(f"Dockerfile.test_intel-psmp", args.check) as f:
         f.write(toolchain_intel() + regtest("psmp", intel=True))
 
-    with OutputFile(f"Dockerfile.prod_intel_psmp", args.check) as f:
-        f.write(
-            toolchain_intel() + production("psmp", "Linux-intel-x86_64", intel=True)
-        )
-
     with OutputFile(f"Dockerfile.test_nvhpc", args.check) as f:
         f.write(toolchain_nvhpc())
 
@@ -47,7 +39,7 @@ def main() -> None:
         f.write(toolchain_full() + regtest("sdbg", "minimal"))
 
     with OutputFile(f"Dockerfile.test_cmake", args.check) as f:
-        f.write(toolchain_full() + install_cp2k_cmake())
+        f.write(spack_env_toolchain() + regtest_cmake())
 
     for version in "ssmp", "psmp":
         with OutputFile(f"Dockerfile.test_asan-{version}", args.check) as f:
@@ -59,8 +51,16 @@ def main() -> None:
 
     for gcc_version in 8, 9, 10, 11, 12:
         with OutputFile(f"Dockerfile.test_gcc{gcc_version}", args.check) as f:
-            img = "ubuntu:22.04" if gcc_version > 8 else "ubuntu:20.04"
-            f.write(toolchain_ubuntu_nompi(base_image=img, gcc_version=gcc_version))
+            if gcc_version > 8:
+                f.write(toolchain_ubuntu_nompi(gcc_version=gcc_version))
+            else:
+                f.write(
+                    toolchain_ubuntu_nompi(
+                        base_image="ubuntu:20.04",
+                        gcc_version=gcc_version,
+                        libgrpp=False,
+                    )
+                )
             # Skip some tests because of bug in LDA_C_PMGB06 functional in libxc <5.2.0.
             f.write(regtest("ssmp", testopts="--skipdir=QS/regtest-rs-dhft"))
 
@@ -85,9 +85,6 @@ def main() -> None:
         with OutputFile(f"Dockerfile.test_cuda_{gpu_ver}", args.check) as f:
             f.write(toolchain_cuda(gpu_ver=gpu_ver) + regtest("psmp", "local_cuda"))
 
-        with OutputFile(f"Dockerfile.prod_cuda_{gpu_ver}", args.check) as f:
-            f.write(toolchain_cuda(gpu_ver=gpu_ver) + production("psmp", "local_cuda"))
-
         with OutputFile(f"Dockerfile.test_hip_cuda_{gpu_ver}", args.check) as f:
             f.write(toolchain_hip_cuda(gpu_ver=gpu_ver) + regtest("psmp", "local_hip"))
 
@@ -133,7 +130,7 @@ def regtest(
 ARG TESTOPTS="{testopts}"
 COPY ./tools/docker/scripts/test_regtest.sh ./
 RUN /bin/bash -o pipefail -c " \
-    TESTOPTS="${{TESTOPTS}}" \
+    TESTOPTS='${{TESTOPTS}}' \
     ./test_regtest.sh '{arch}' '{version}' |& tee report.log && \
     rm -rf regtesting"
 """
@@ -141,6 +138,31 @@ RUN /bin/bash -o pipefail -c " \
     )
 
 
+# ======================================================================================
+def regtest_cmake(testopts: str = "") -> str:
+    return (
+        rf"""
+# Install CP2K sources.
+WORKDIR /opt/cp2k
+COPY ./src ./src
+COPY ./data ./data
+COPY ./tests ./tests
+COPY ./tools/build_utils ./tools/build_utils
+COPY ./cmake ./cmake
+COPY ./CMakeLists.txt .
+
+# Build CP2K with CMake and run regression tests.
+ARG TESTOPTS="{testopts}"
+COPY ./tools/docker/scripts/test_regtest_cmake.sh ./
+RUN /bin/bash -o pipefail -c " \
+    TESTOPTS='${{TESTOPTS}}' \
+    ./test_regtest_cmake.sh |& tee report.log && \
+    rm -rf regtesting"
+"""
+        + print_cached_report()
+    )
+
+
 # ======================================================================================
 def regtest_postponed(version: str, arch: str = "local") -> str:
     return (
@@ -227,9 +249,8 @@ def manual() -> str:
         install_cp2k(version="psmp", arch="local", revision=True)
         + rf"""
 # Generate manual.
-COPY ./tools/manual ./tools/manual
-COPY ./tools/input_editing ./tools/input_editing
 COPY ./docs ./docs
+COPY ./tools/input_editing ./tools/input_editing
 COPY ./tools/docker/scripts/test_manual.sh .
 ARG ADD_EDIT_LINKS=yes
 RUN ./test_manual.sh "${{ADD_EDIT_LINKS}}" 2>&1 | tee report.log
@@ -248,6 +269,7 @@ FROM ubuntu:22.04
 WORKDIR /opt/cp2k-precommit
 COPY ./tools/precommit/ /opt/cp2k-precommit/
 RUN ./install_requirements.sh
+ENV PATH="/opt/venv/bin:$PATH"
 
 # Install sources.
 WORKDIR /opt/cp2k
@@ -291,6 +313,7 @@ COPY ./exts ./exts
 COPY ./data ./data
 COPY ./docs ./docs
 COPY ./tools ./tools
+COPY ./tests ./tests
 COPY ./cmake ./cmake
 COPY ./CMakeLists.txt .
 COPY ./Makefile .
@@ -315,35 +338,11 @@ ENTRYPOINT []
 """
 
 
-# ======================================================================================
-def production(version: str, arch: str = "local", intel: bool = False) -> str:
-    return (
-        install_cp2k(version=version, arch=arch, revision=True, prod=True, intel=intel)
-        + rf"""
-# Run regression tests.
-ARG TESTOPTS
-RUN /bin/bash -c " \
-    source /opt/cp2k-toolchain/install/setup && \
-    ./tools/regtesting/do_regtest.py '{arch}' '{version}' "${{TESTOPTS}}" |& tee regtests.log && \
-    rm -rf regtesting"
-
-# Setup entry point for production.
-COPY ./tools/docker/scripts/prod_entrypoint.sh ./
-WORKDIR /mnt
-ENTRYPOINT ["/opt/cp2k/prod_entrypoint.sh", "{arch}", "{version}"]
-CMD ["cp2k", "--help"]
-
-#EOF
-"""
-    )
-
-
 # ======================================================================================
 def install_cp2k(
     version: str,
     arch: str,
     revision: bool = False,
-    prod: bool = False,
     intel: bool = False,
 ) -> str:
     input_lines = []
@@ -352,8 +351,8 @@ def install_cp2k(
     if revision:
         input_lines.append("ARG GIT_COMMIT_SHA")
         run_lines.append(
-            'if [ -n "${GIT_COMMIT_SHA}" ] ; then'
-            ' echo "git:\${GIT_COMMIT_SHA::7}" > REVISION; fi'
+            r'if [ -n "${GIT_COMMIT_SHA}" ] ; then'
+            r' echo "git:\${GIT_COMMIT_SHA::7}" > REVISION; fi'
         )
 
     input_lines.append("COPY ./Makefile .")
@@ -369,27 +368,6 @@ def install_cp2k(
         input_lines.append(f"COPY ./arch/{arch}.{version} /opt/cp2k/arch/")
         run_lines.append(f"ln -s /opt/cp2k-toolchain /opt/cp2k/tools/toolchain")
 
-    run_lines.append("echo 'Compiling cp2k...'")
-    run_lines.append("source /opt/cp2k-toolchain/install/setup")
-
-    build_command = f"make -j ARCH={arch} VERSION={version}"
-    if prod:
-        run_lines.append(build_command)
-        run_lines.append(f"ln -sf ./cp2k.{version} ./exe/{arch}/cp2k")
-        run_lines.append(f"ln -sf ./cp2k_shell.{version} ./exe/{arch}/cp2k_shell")
-        run_lines.append(f"ln -sf ./graph.{version} ./exe/{arch}/graph")
-        run_lines.append(f"ln -sf ./dumpdcd.{version} ./exe/{arch}/dumpdcd")
-        run_lines.append(f"ln -sf ./xyz2dcd.{version} ./exe/{arch}/xyz2dcd")
-        run_lines.append(f"rm -rf lib obj exe/{arch}/libcp2k_unittest.{version}")
-    else:
-        run_lines.append(f"( {build_command} &> /dev/null || true )")
-        run_lines.append(f"rm -rf lib obj")
-
-    # Ensure MPI is dynamically linked, which is needed e.g. for Shifter.
-    if version.startswith("p") and not intel:
-        binary = f"./exe/{arch}/cp2k.{version}"
-        run_lines.append(f"( [ ! -f {binary} ] || ldd {binary} | grep -q libmpi )")
-
     input_block = "\n".join(input_lines)
     run_block = " && \\\n    ".join(run_lines)
 
@@ -405,26 +383,6 @@ COPY ./tools/regtesting ./tools/regtesting
 """
 
 
-# ======================================================================================
-def install_cp2k_cmake() -> str:
-    return (
-        rf"""
-
-# Install CP2K using CMake.
-WORKDIR /opt/cp2k
-COPY ./src ./src
-COPY ./exts ./exts
-COPY ./tools/build_utils ./tools/build_utils
-COPY ./cmake ./cmake
-COPY ./CMakeLists.txt .
-
-COPY ./tools/docker/scripts/test_cmake.sh .
-RUN ./test_cmake.sh 2>&1 | tee report.log
-"""
-        + print_cached_report()
-    )
-
-
 # ======================================================================================
 def toolchain_full(
     base_image: str = "ubuntu:22.04", with_gcc: str = "system", **kwargs: str
@@ -438,6 +396,7 @@ def toolchain_full(
 def toolchain_ubuntu_nompi(
     base_image: str = "ubuntu:22.04",
     gcc_version: int = 12,
+    libgrpp: bool = True,
     libvori: bool = True,
 ) -> str:
     output = rf"""
@@ -476,6 +435,7 @@ RUN ln -sf /usr/bin/gcc-{gcc_version}      /usr/local/bin/gcc  && \
         with_openblas="system",
         with_gsl="system",
         with_hdf5="system",
+        with_libgrpp=("install" if libgrpp else "no"),
         with_libint=("system" if gcc_version > 8 else "install"),
         with_libxc=("system" if gcc_version > 8 else "install"),
         with_libxsmm="install",
@@ -487,7 +447,10 @@ RUN ln -sf /usr/bin/gcc-{gcc_version}      /usr/local/bin/gcc  && \
 # ======================================================================================
 def toolchain_intel() -> str:
     return rf"""
-FROM intel/oneapi-hpckit:2023.0.0-devel-ubuntu22.04
+FROM intel/oneapi-hpckit:2023.2.1-devel-ubuntu22.04
+
+# Workaround expired key.
+RUN curl -sS https://apt.repos.intel.com/intel-gpg-keys/GPG-PUB-KEY-INTEL-SW-PRODUCTS.PUB | gpg --dearmor > /usr/share/keyrings/intel-oneapi-archive-keyring.gpg
 
 """ + install_toolchain(
         base_image="ubuntu",
@@ -771,6 +734,67 @@ RUN ./scripts/generate_arch_files.sh && rm -rf ./build
 """.lstrip()
 
 
+# ======================================================================================
+def spack_env_toolchain() -> str:
+    return rf"""
+FROM ubuntu:22.04
+
+# Install common dependencies as pre-built Ubuntu packages.
+RUN apt-get update -qq && apt-get install -qq --no-install-recommends \
+    autoconf \
+    autogen \
+    automake \
+    autotools-dev \
+    bzip2 \
+    ca-certificates \
+    g++ \
+    gcc \
+    gfortran \
+    git \
+    less \
+    libtool \
+    libtool-bin \
+    make \
+    nano \
+    ninja-build \
+    patch \
+    pkgconf \
+    python3 \
+    unzip \
+    wget \
+    xxd \
+    zlib1g-dev \
+    cmake \
+    gnupg \
+    m4 \
+    xz-utils \
+    libssl-dev \
+    libssh-dev \
+    hwloc \
+    libhwloc-dev \
+   && rm -rf /var/lib/apt/lists/*
+
+# Install a recent developer version of Spack.
+WORKDIR /opt/spack
+RUN git init --quiet && \
+    git remote add origin https://github.com/spack/spack.git && \
+    git fetch --quiet --depth 1 origin 8bcb1f8766ffbf097ec685bdafad53bc8b6e9e30 && \
+    git checkout --quiet FETCH_HEAD
+ENV PATH="/opt/spack/bin:${{PATH}}"
+
+# Find all external packages and compilers.
+RUN spack external find --all --not-buildable 
+RUN spack compiler find
+
+# Install CP2K's dependencies via Spack.
+WORKDIR /
+COPY ./tools/spack/cp2k-dependencies.yaml .
+RUN spack env create myenv ./cp2k-dependencies.yaml
+RUN spack -e myenv concretize -f
+RUN spack -e myenv env depfile -o spack-makefile && make -j32 --file=spack-makefile SPACK_COLOR=never --output-sync=recurse
+"""
+
+
 # ======================================================================================
 class OutputFile:
     def __init__(self, filename: str, check: bool) -> None:
