@@ -170,6 +170,9 @@ The --with-PKG options follow the rules:
   --with-libint           libint, library for evaluation of two-body molecular
                           integrals, needed for hybrid functional calculations
                           Default = install
+  --with-libgrpp          libgrpp, library for the evaluation of ECP integrals, needed
+                          for any calculations with semi-local ECP pseudopotentials 
+                          Default = install
   --with-fftw             FFTW3, library for fast fourier transform
                           Default = install
   --with-acml             AMD core maths library, which provides LAPACK and BLAS
@@ -259,7 +262,7 @@ EOF
 tool_list="gcc intel cmake"
 mpi_list="mpich openmpi intelmpi"
 math_list="mkl acml openblas"
-lib_list="fftw libint libxc libxsmm cosma scalapack elpa cusolvermp plumed \
+lib_list="fftw libint libxc libgrpp libxsmm cosma scalapack elpa cusolvermp plumed \
           spfft spla ptscotch superlu pexsi quip gsl spglib hdf5 libvdwxc sirius
           libvori libtorch"
 package_list="${tool_list} ${mpi_list} ${math_list} ${lib_list}"
@@ -280,6 +283,7 @@ with_gcc="__SYSTEM__"
 # libs to turn on by default, the math and mpi libraries are chosen by there respective modes:
 with_fftw="__INSTALL__"
 with_libint="__INSTALL__"
+with_libgrpp="__INSTALL__"
 with_libxsmm="__INSTALL__"
 with_libxc="__INSTALL__"
 with_scalapack="__INSTALL__"
@@ -560,6 +564,9 @@ while [ $# -ge 1 ]; do
     --with-libxc*)
       with_libxc=$(read_with "${1}")
       ;;
+    --with-libgrpp*)
+      with_libgrpp=$(read_with "${1}")
+      ;;
     --with-fftw*)
       with_fftw=$(read_with "${1}")
       ;;
